==> 2.11.0.tar.gz: lib/src/verival.dart <==
import 'dart:async';
import 'dart:convert';

import 'peer_info.dart';

import 'net_addr.dart';
import 'package:http/http.dart' as http;
import 'crypto.dart';

class Verival {
  static final _verival = NetAddr.fromString("yonafediverse.com:3333");

  static publish(PeerInfo info, List<int> sk) async {
    var data = info.toMap();
    data["pk"] = base64UrlEncode(Crypto.derivePK(sk).sublist(0, 32));
    data["time"] =
        (DateTime.now().microsecondsSinceEpoch ~/ 1000000).toString();
    var payload = Uri(queryParameters: data).query;
    var sig =
        base64UrlEncode(await Crypto.sign(sk, utf8.encoder.convert(payload)));
    var resp = await http.put(Verival._verival.toUri(scheme: "http"),
        body: "$sig&$payload");
    if (resp.statusCode != 204) {
      throw Exception(resp.body.isEmpty ? resp.statusCode : resp.body);
    }
  }

  static Future<PeerInfo> lookup(List<int> pk, Duration timeout) async {
    var cli = http.Client();
    var timer = Timer(timeout, () {
      cli.close();
    });
    try {
      var res = await cli.get(Verival._verival.toUri(
          scheme: "http", pathSegments: [base64UrlEncode(pk.sublist(0, 32))]));
      if (res.statusCode != 200) {
        throw Exception(res.body.isEmpty ? res.statusCode : res.body);
      }
      var ampersandIndex = res.body.indexOf('&');
      var signature = base64Decode(res.body.substring(0, ampersandIndex));
      var payload = res.body.substring(ampersandIndex + 1);
      var data = Uri.splitQueryString(payload);
      if (true !=
          await Crypto.verify(utf8.encoder.convert(payload), signature,
              base64Decode(data["pk"]!))) {
        throw Exception("cloud not verify peer");
      }
      return PeerInfo.fromMap(data);
    } finally {
      cli.close();
      if (timer.isActive) {
        timer.cancel();
      }
    }
  }
}

==> 3.1.0.tar.gz: lib/src/verival.dart <==
import 'dart:async';
import 'dart:convert';
import 'excache.dart';

import 'peer_info.dart';
import 'net_addr.dart';
import 'package:http/http.dart' as http;
import 'crypto.dart';


class Verival {
  static final _cache = LookupCache<PeerInfo>(Duration(seconds: 5));
  static final _verival = NetAddr.fromString("yonafediverse.com:3333");
  static publish(PeerInfo info, List<int> sk) async {
    var data = info.toMap();
    data["pk"] = base64UrlEncode(Crypto.derivePK(sk).sublist(0, 32));
    data["time"] =
        (DateTime.now().microsecondsSinceEpoch ~/ 1000000).toString();
    var payload = Uri(queryParameters: data).query;
    var sig =
        base64UrlEncode(await Crypto.sign(sk, utf8.encoder.convert(payload)));
    var resp = await http.put(Verival._verival.toUri(scheme: "http"),
        body: "$sig&$payload");
    if (resp.statusCode != 204) {
      throw Exception(resp.body.isEmpty ? resp.statusCode : resp.body);
    }
  }

  static Future<PeerInfo> lookup(List<int> pk, Duration timeout) async {
    Verival._cache.clean();
    var b64 = Base64Codec().encode(pk);
    var found = Verival._cache.get(b64);
    if(found != null){
      return found;
    }
    var cli = http.Client();
    var timer = Timer(timeout, () {
      cli.close();
    });
    try {
      var res = await cli.get(Verival._verival.toUri(
          scheme: "http", pathSegments: [base64UrlEncode(pk.sublist(0, 32))]));
      if (res.statusCode != 200) {
        throw Exception(res.body.isEmpty ? res.statusCode : res.body);
      }
      var ampersandIndex = res.body.indexOf('&');
      var signature = base64Decode(res.body.substring(0, ampersandIndex));
      var payload = res.body.substring(ampersandIndex + 1);
      var data = Uri.splitQueryString(payload);
      if (true !=
          await Crypto.verify(utf8.encoder.convert(payload), signature,
              base64Decode(data["pk"]!))) {
        throw Exception("cloud not verify peer");
      }
      var info = PeerInfo.fromMap(data);
      Verival._cache.set(b64, info,info.deadline);
      return info;
    } finally {
      cli.close();
      if (timer.isActive) {
        timer.cancel();
      }
    }
  }
}
